package com.ramcosta.composedestinations.navargs.utils

import android.annotation.SuppressLint
import android.os.Build
import android.util.Base64
import java.net.URLEncoder
import java.nio.charset.StandardCharsets

fun encodeForRoute(arg: String): String {
    return URLEncoder.encode(arg, StandardCharsets.UTF_8.toString())
}

@SuppressLint("NewApi")
internal fun String.base64ToByteArray(): ByteArray {
    return if (shouldUseJavaUtil) {
        java.util.Base64.getUrlDecoder().decode(toByteArray(StandardCharsets.UTF_8))
    } else {
        Base64.decode(toByteArray(StandardCharsets.UTF_8), Base64.URL_SAFE or Base64.NO_WRAP)
    }
}

@SuppressLint("NewApi")
internal fun ByteArray.toBase64Str(): String {
    return if (shouldUseJavaUtil) {
        java.util.Base64.getUrlEncoder().encodeToString(this)
    } else {
        Base64.encodeToString(this, Base64.URL_SAFE or Base64.NO_WRAP)
    }
}

// Both encode/decode from java util and android util seem to
// do exactly the same.
// android.util one doesn't work on Unit tests and java.util doesn't work
// on older devices.
// Also, on unit tests SDK_INT is 0, but we're running on the developer's machine
// So we can still use java.util in that case
@SuppressLint("ObsoleteSdkInt")
private val shouldUseJavaUtil =
    Build.VERSION.SDK_INT >= Build.VERSION_CODES.O || Build.VERSION.SDK_INT == 0
